@@ -37,7 +37,7 @@ class JVCProjector:
         # Can supply a logger object. It can hook into the HA logger
         logger: logging.Logger = logging.getLogger(__name__),
         port: int = 20554,
-        connect_timeout: int = 10,
+        connect_timeout: int = 5,
     ):
         self.host = host
         self.port = port
@@ -72,7 +72,7 @@ class JVCProjector:
                     "Connecting to JVC Projector: %s:%s", self.host, self.port
                 )
                 self.client = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-                self.client.settimeout(10)
+                self.client.settimeout(self.connect_timeout)
 
                 self.client.connect((self.host, self.port))
                 self.logger.info("Connected to JVC Projector")
@@ -266,14 +266,14 @@ class JVCProjector:
                 received_msg = self.client.recv(len(ack_value))
             except socket.timeout:
                 self.logger.error(
-                    "Connection timed out. Command %s is probably not allowed to run at this time.",
+                    # TODO: this may be happening because something else read the response?
+                    "Connection timed out. Command %s may not be allowed to run at this time or something else is running already.",
                     command,
                 )
                 self.logger.debug("restarting connection")
                 self.client.close()
                 self.reconnect()
-                # don't retry a timeout
-                retry_count += 10
+                retry_count += 1
                 return
 
             except ConnectionRefusedError:
@@ -495,14 +495,14 @@ class JVCProjector:
 
     def get_hdr_processing(self) -> str:
         """
-        Get the current hdr processing setting like frame by frame
+        Get the current hdr processing setting like frame by frame. Will fail if not in HDR mode!
         """
         state, _ = self._do_reference_op("hdr_processing", ACKs.picture_ack)
         return HdrProcessing(state.replace(ACKs.picture_ack.value, b"")).name
 
     def get_theater_optimizer_state(self) -> str:
         """
-        If theater optimizer is on/off
+        If theater optimizer is on/off Will fail if not in HDR mode!
         """
         state, _ = self._do_reference_op("theater_optimizer", ACKs.picture_ack)
         return TheaterOptimizer(state.replace(ACKs.picture_ack.value, b"")).name
